@@ -17,6 +17,7 @@ class AppLayout(object):
         self.request = request
         self.home_url = request.application_url
         self.headings = []
+        self.portlets = (Thing1(), Thing2(), LittleCat("A"))
 
     @property
     def project_title(self):
@@ -24,3 +25,20 @@ class AppLayout(object):
 
     def add_heading(self, name, *args, **kw):
         self.headings.append((name, args, kw))
+
+
+class Thing1(object):
+    title = "Thing 1"
+    content = "I am Thing 1!"
+
+
+class Thing2(object):
+    title = "Thing 2"
+    content = "I am Thing 2!"
+
+
+class LittleCat(object):
+    talent = "removing pink spots"
+
+    def __init__(self, name):
+        self.name = name
